==> deepsignal2-0.1.2.tar.gz: deepsignal2-0.1.2/setup.py <==
from __future__ import print_function
from setuptools import setup
from setuptools.command.test import test as TestCommand
import codecs
import os
import sys
import re

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = ['--strict', '--verbose', '--tb=long', 'tests']
        self.test_suite = True

    def run_tests(self):
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


long_description = read('README.rst')


setup(
    name='deepsignal2',
    packages=['deepsignal2'],
    keywords=['methylation', 'nanopore', 'neural network'],
    version=find_version('deepsignal2', '__init__.py'),
    url='https://github.com/PengNi/deepsignal2',
    download_url='https://github.com/PengNi/deepsignal2/archive/0.1.2.tar.gz',
    license='GNU General Public License v3 (GPLv3)',
    author='Peng Ni',
    # tests_require=['pytest'],
    install_requires=['numpy>=1.15.3',
                      'h5py>=2.8.0',
                      'statsmodels>=0.9.0',
                      'scikit-learn>=0.20.1',
                      'torch>=1.2.0,<=1.7.0',
                      ],
    # cmdclass={'test': PyTest},
    author_email='543943952@qq.com',
    description='A deep-learning method for detecting DNA methylation state '
                'from Oxford Nanopore sequencing reads',
    long_description=long_description,
    entry_points={
        'console_scripts': [
            'deepsignal2=deepsignal2.deepsignal2:main',
            ],
        },
    platforms='any',
    # test_suite='test',
    zip_safe=False,
    include_package_data=True,
    # package_data={'deepsignal': ['utils/*']},
    classifiers=[
        'Programming Language :: Python :: 3',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        ],
    # extras_require={
    #     'testing': ['pytest'],
    #   },
)

==> deepsignal2-0.1.3.tar.gz: deepsignal2-0.1.3/setup.py <==
from __future__ import print_function
from setuptools import setup
from setuptools.command.test import test as TestCommand
import codecs
import os
import sys
import re

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


__version__ = find_version('deepsignal2', '__init__.py')


# class PyTest(TestCommand):
#     def finalize_options(self):
#         TestCommand.finalize_options(self)
#         self.test_args = ['--strict', '--verbose', '--tb=long', 'tests']
#         self.test_suite = True
#
#     def run_tests(self):
#         import pytest
#         errno = pytest.main(self.test_args)
#         sys.exit(errno)


long_description = read('README.rst')


with open('requirements.txt', 'r') as rf:
    required = rf.read().splitlines()


setup(
    name='deepsignal2',
    packages=['deepsignal2'],
    keywords=['methylation', 'nanopore', 'neural network'],
    version=__version__,
    url='https://github.com/PengNi/deepsignal2',
    download_url='https://github.com/PengNi/deepsignal2/archive/{}.tar.gz'.format(__version__),
    license='GNU General Public License v3 (GPLv3)',
    author='Peng Ni',
    # tests_require=['pytest'],
    # install_requires=['numpy>=1.15.3',
    #                   'h5py>=2.8.0',
    #                   'statsmodels>=0.9.0',
    #                   'scikit-learn>=0.20.1',
    #                   'torch>=1.2.0,<=1.7.0',
    #                   ],
    install_requires=required,
    # cmdclass={'test': PyTest},
    author_email='543943952@qq.com',
    description='A deep-learning method for detecting DNA methylation state '
                'from Oxford Nanopore sequencing reads',
    long_description=long_description,
    entry_points={
        'console_scripts': [
            'deepsignal2=deepsignal2.deepsignal2:main',
            ],
        },
    platforms='any',
    # test_suite='test',
    zip_safe=False,
    include_package_data=True,
    # package_data={'deepsignal': ['utils/*']},
    classifiers=[
        'Programming Language :: Python :: 3',
        'Development Status :: 4 - Beta',
        'Natural Language :: English',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        ],
    # extras_require={
    #     'testing': ['pytest'],
    #   },
)
